# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResponderExecution(object):
    """
    Responder Execution Object.
    """

    #: A constant which can be used with the responder_rule_type property of a ResponderExecution.
    #: This constant has a value of "REMEDIATION"
    RESPONDER_RULE_TYPE_REMEDIATION = "REMEDIATION"

    #: A constant which can be used with the responder_rule_type property of a ResponderExecution.
    #: This constant has a value of "NOTIFICATION"
    RESPONDER_RULE_TYPE_NOTIFICATION = "NOTIFICATION"

    #: A constant which can be used with the responder_execution_status property of a ResponderExecution.
    #: This constant has a value of "STARTED"
    RESPONDER_EXECUTION_STATUS_STARTED = "STARTED"

    #: A constant which can be used with the responder_execution_status property of a ResponderExecution.
    #: This constant has a value of "AWAITING_CONFIRMATION"
    RESPONDER_EXECUTION_STATUS_AWAITING_CONFIRMATION = "AWAITING_CONFIRMATION"

    #: A constant which can be used with the responder_execution_status property of a ResponderExecution.
    #: This constant has a value of "AWAITING_INPUT"
    RESPONDER_EXECUTION_STATUS_AWAITING_INPUT = "AWAITING_INPUT"

    #: A constant which can be used with the responder_execution_status property of a ResponderExecution.
    #: This constant has a value of "SUCCEEDED"
    RESPONDER_EXECUTION_STATUS_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the responder_execution_status property of a ResponderExecution.
    #: This constant has a value of "FAILED"
    RESPONDER_EXECUTION_STATUS_FAILED = "FAILED"

    #: A constant which can be used with the responder_execution_status property of a ResponderExecution.
    #: This constant has a value of "SKIPPED"
    RESPONDER_EXECUTION_STATUS_SKIPPED = "SKIPPED"

    #: A constant which can be used with the responder_execution_status property of a ResponderExecution.
    #: This constant has a value of "ALL"
    RESPONDER_EXECUTION_STATUS_ALL = "ALL"

    #: A constant which can be used with the responder_execution_mode property of a ResponderExecution.
    #: This constant has a value of "MANUAL"
    RESPONDER_EXECUTION_MODE_MANUAL = "MANUAL"

    #: A constant which can be used with the responder_execution_mode property of a ResponderExecution.
    #: This constant has a value of "AUTOMATED"
    RESPONDER_EXECUTION_MODE_AUTOMATED = "AUTOMATED"

    #: A constant which can be used with the responder_execution_mode property of a ResponderExecution.
    #: This constant has a value of "ALL"
    RESPONDER_EXECUTION_MODE_ALL = "ALL"

    def __init__(self, **kwargs):
        """
        Initializes a new ResponderExecution object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ResponderExecution.
        :type id: str

        :param responder_rule_id:
            The value to assign to the responder_rule_id property of this ResponderExecution.
        :type responder_rule_id: str

        :param responder_rule_type:
            The value to assign to the responder_rule_type property of this ResponderExecution.
            Allowed values for this property are: "REMEDIATION", "NOTIFICATION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type responder_rule_type: str

        :param responder_rule_name:
            The value to assign to the responder_rule_name property of this ResponderExecution.
        :type responder_rule_name: str

        :param problem_id:
            The value to assign to the problem_id property of this ResponderExecution.
        :type problem_id: str

        :param region:
            The value to assign to the region property of this ResponderExecution.
        :type region: str

        :param target_id:
            The value to assign to the target_id property of this ResponderExecution.
        :type target_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ResponderExecution.
        :type compartment_id: str

        :param resource_type:
            The value to assign to the resource_type property of this ResponderExecution.
        :type resource_type: str

        :param resource_name:
            The value to assign to the resource_name property of this ResponderExecution.
        :type resource_name: str

        :param time_created:
            The value to assign to the time_created property of this ResponderExecution.
        :type time_created: datetime

        :param time_completed:
            The value to assign to the time_completed property of this ResponderExecution.
        :type time_completed: datetime

        :param responder_execution_status:
            The value to assign to the responder_execution_status property of this ResponderExecution.
            Allowed values for this property are: "STARTED", "AWAITING_CONFIRMATION", "AWAITING_INPUT", "SUCCEEDED", "FAILED", "SKIPPED", "ALL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type responder_execution_status: str

        :param responder_execution_mode:
            The value to assign to the responder_execution_mode property of this ResponderExecution.
            Allowed values for this property are: "MANUAL", "AUTOMATED", "ALL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type responder_execution_mode: str

        :param message:
            The value to assign to the message property of this ResponderExecution.
        :type message: str

        :param responder_rule_execution_details:
            The value to assign to the responder_rule_execution_details property of this ResponderExecution.
        :type responder_rule_execution_details: oci.cloud_guard.models.ResponderRuleExecutionDetails

        """
        self.swagger_types = {
            'id': 'str',
            'responder_rule_id': 'str',
            'responder_rule_type': 'str',
            'responder_rule_name': 'str',
            'problem_id': 'str',
            'region': 'str',
            'target_id': 'str',
            'compartment_id': 'str',
            'resource_type': 'str',
            'resource_name': 'str',
            'time_created': 'datetime',
            'time_completed': 'datetime',
            'responder_execution_status': 'str',
            'responder_execution_mode': 'str',
            'message': 'str',
            'responder_rule_execution_details': 'ResponderRuleExecutionDetails'
        }

        self.attribute_map = {
            'id': 'id',
            'responder_rule_id': 'responderRuleId',
            'responder_rule_type': 'responderRuleType',
            'responder_rule_name': 'responderRuleName',
            'problem_id': 'problemId',
            'region': 'region',
            'target_id': 'targetId',
            'compartment_id': 'compartmentId',
            'resource_type': 'resourceType',
            'resource_name': 'resourceName',
            'time_created': 'timeCreated',
            'time_completed': 'timeCompleted',
            'responder_execution_status': 'responderExecutionStatus',
            'responder_execution_mode': 'responderExecutionMode',
            'message': 'message',
            'responder_rule_execution_details': 'responderRuleExecutionDetails'
        }

        self._id = None
        self._responder_rule_id = None
        self._responder_rule_type = None
        self._responder_rule_name = None
        self._problem_id = None
        self._region = None
        self._target_id = None
        self._compartment_id = None
        self._resource_type = None
        self._resource_name = None
        self._time_created = None
        self._time_completed = None
        self._responder_execution_status = None
        self._responder_execution_mode = None
        self._message = None
        self._responder_rule_execution_details = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ResponderExecution.
        The unique identifier of the responder execution


        :return: The id of this ResponderExecution.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ResponderExecution.
        The unique identifier of the responder execution


        :param id: The id of this ResponderExecution.
        :type: str
        """
        self._id = id

    @property
    def responder_rule_id(self):
        """
        **[Required]** Gets the responder_rule_id of this ResponderExecution.
        Responder Rule id for the responder execution


        :return: The responder_rule_id of this ResponderExecution.
        :rtype: str
        """
        return self._responder_rule_id

    @responder_rule_id.setter
    def responder_rule_id(self, responder_rule_id):
        """
        Sets the responder_rule_id of this ResponderExecution.
        Responder Rule id for the responder execution


        :param responder_rule_id: The responder_rule_id of this ResponderExecution.
        :type: str
        """
        self._responder_rule_id = responder_rule_id

    @property
    def responder_rule_type(self):
        """
        **[Required]** Gets the responder_rule_type of this ResponderExecution.
        Rule Type for the responder execution

        Allowed values for this property are: "REMEDIATION", "NOTIFICATION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The responder_rule_type of this ResponderExecution.
        :rtype: str
        """
        return self._responder_rule_type

    @responder_rule_type.setter
    def responder_rule_type(self, responder_rule_type):
        """
        Sets the responder_rule_type of this ResponderExecution.
        Rule Type for the responder execution


        :param responder_rule_type: The responder_rule_type of this ResponderExecution.
        :type: str
        """
        allowed_values = ["REMEDIATION", "NOTIFICATION"]
        if not value_allowed_none_or_none_sentinel(responder_rule_type, allowed_values):
            responder_rule_type = 'UNKNOWN_ENUM_VALUE'
        self._responder_rule_type = responder_rule_type

    @property
    def responder_rule_name(self):
        """
        **[Required]** Gets the responder_rule_name of this ResponderExecution.
        Rule name for the responder execution


        :return: The responder_rule_name of this ResponderExecution.
        :rtype: str
        """
        return self._responder_rule_name

    @responder_rule_name.setter
    def responder_rule_name(self, responder_rule_name):
        """
        Sets the responder_rule_name of this ResponderExecution.
        Rule name for the responder execution


        :param responder_rule_name: The responder_rule_name of this ResponderExecution.
        :type: str
        """
        self._responder_rule_name = responder_rule_name

    @property
    def problem_id(self):
        """
        **[Required]** Gets the problem_id of this ResponderExecution.
        Problem id associated with the responder execution


        :return: The problem_id of this ResponderExecution.
        :rtype: str
        """
        return self._problem_id

    @problem_id.setter
    def problem_id(self, problem_id):
        """
        Sets the problem_id of this ResponderExecution.
        Problem id associated with the responder execution


        :param problem_id: The problem_id of this ResponderExecution.
        :type: str
        """
        self._problem_id = problem_id

    @property
    def region(self):
        """
        **[Required]** Gets the region of this ResponderExecution.
        region where the problem is found


        :return: The region of this ResponderExecution.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this ResponderExecution.
        region where the problem is found


        :param region: The region of this ResponderExecution.
        :type: str
        """
        self._region = region

    @property
    def target_id(self):
        """
        **[Required]** Gets the target_id of this ResponderExecution.
        targetId of the problem for the responder execution


        :return: The target_id of this ResponderExecution.
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """
        Sets the target_id of this ResponderExecution.
        targetId of the problem for the responder execution


        :param target_id: The target_id of this ResponderExecution.
        :type: str
        """
        self._target_id = target_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ResponderExecution.
        compartment id of the responder execution for the problem


        :return: The compartment_id of this ResponderExecution.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ResponderExecution.
        compartment id of the responder execution for the problem


        :param compartment_id: The compartment_id of this ResponderExecution.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def resource_type(self):
        """
        **[Required]** Gets the resource_type of this ResponderExecution.
        resource type of the problem for the responder execution


        :return: The resource_type of this ResponderExecution.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """
        Sets the resource_type of this ResponderExecution.
        resource type of the problem for the responder execution


        :param resource_type: The resource_type of this ResponderExecution.
        :type: str
        """
        self._resource_type = resource_type

    @property
    def resource_name(self):
        """
        **[Required]** Gets the resource_name of this ResponderExecution.
        resource name of the problem for the responder execution. TODO-DOC link to resource definition doc


        :return: The resource_name of this ResponderExecution.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """
        Sets the resource_name of this ResponderExecution.
        resource name of the problem for the responder execution. TODO-DOC link to resource definition doc


        :param resource_name: The resource_name of this ResponderExecution.
        :type: str
        """
        self._resource_name = resource_name

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ResponderExecution.
        The date and time the responder execution was created. Format defined by RFC3339.


        :return: The time_created of this ResponderExecution.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ResponderExecution.
        The date and time the responder execution was created. Format defined by RFC3339.


        :param time_created: The time_created of this ResponderExecution.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_completed(self):
        """
        Gets the time_completed of this ResponderExecution.
        The date and time the responder execution was updated. Format defined by RFC3339.


        :return: The time_completed of this ResponderExecution.
        :rtype: datetime
        """
        return self._time_completed

    @time_completed.setter
    def time_completed(self, time_completed):
        """
        Sets the time_completed of this ResponderExecution.
        The date and time the responder execution was updated. Format defined by RFC3339.


        :param time_completed: The time_completed of this ResponderExecution.
        :type: datetime
        """
        self._time_completed = time_completed

    @property
    def responder_execution_status(self):
        """
        **[Required]** Gets the responder_execution_status of this ResponderExecution.
        current execution status of the responder

        Allowed values for this property are: "STARTED", "AWAITING_CONFIRMATION", "AWAITING_INPUT", "SUCCEEDED", "FAILED", "SKIPPED", "ALL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The responder_execution_status of this ResponderExecution.
        :rtype: str
        """
        return self._responder_execution_status

    @responder_execution_status.setter
    def responder_execution_status(self, responder_execution_status):
        """
        Sets the responder_execution_status of this ResponderExecution.
        current execution status of the responder


        :param responder_execution_status: The responder_execution_status of this ResponderExecution.
        :type: str
        """
        allowed_values = ["STARTED", "AWAITING_CONFIRMATION", "AWAITING_INPUT", "SUCCEEDED", "FAILED", "SKIPPED", "ALL"]
        if not value_allowed_none_or_none_sentinel(responder_execution_status, allowed_values):
            responder_execution_status = 'UNKNOWN_ENUM_VALUE'
        self._responder_execution_status = responder_execution_status

    @property
    def responder_execution_mode(self):
        """
        **[Required]** Gets the responder_execution_mode of this ResponderExecution.
        execution mode of the responder

        Allowed values for this property are: "MANUAL", "AUTOMATED", "ALL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The responder_execution_mode of this ResponderExecution.
        :rtype: str
        """
        return self._responder_execution_mode

    @responder_execution_mode.setter
    def responder_execution_mode(self, responder_execution_mode):
        """
        Sets the responder_execution_mode of this ResponderExecution.
        execution mode of the responder


        :param responder_execution_mode: The responder_execution_mode of this ResponderExecution.
        :type: str
        """
        allowed_values = ["MANUAL", "AUTOMATED", "ALL"]
        if not value_allowed_none_or_none_sentinel(responder_execution_mode, allowed_values):
            responder_execution_mode = 'UNKNOWN_ENUM_VALUE'
        self._responder_execution_mode = responder_execution_mode

    @property
    def message(self):
        """
        Gets the message of this ResponderExecution.
        Message about the responder execution.


        :return: The message of this ResponderExecution.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this ResponderExecution.
        Message about the responder execution.


        :param message: The message of this ResponderExecution.
        :type: str
        """
        self._message = message

    @property
    def responder_rule_execution_details(self):
        """
        Gets the responder_rule_execution_details of this ResponderExecution.

        :return: The responder_rule_execution_details of this ResponderExecution.
        :rtype: oci.cloud_guard.models.ResponderRuleExecutionDetails
        """
        return self._responder_rule_execution_details

    @responder_rule_execution_details.setter
    def responder_rule_execution_details(self, responder_rule_execution_details):
        """
        Sets the responder_rule_execution_details of this ResponderExecution.

        :param responder_rule_execution_details: The responder_rule_execution_details of this ResponderExecution.
        :type: oci.cloud_guard.models.ResponderRuleExecutionDetails
        """
        self._responder_rule_execution_details = responder_rule_execution_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Original Work: Copyright (c) 2018 Character Encoding Detector contributors.  https://github.com/chardet

######################## BEGIN LICENSE BLOCK ########################
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110-1301  USA
######################### END LICENSE BLOCK #########################


from .universaldetector import UniversalDetector
from .enums import InputState
from .version import __version__, VERSION


__all__ = ['UniversalDetector', 'detect', 'detect_all', '__version__', 'VERSION']


def detect(byte_str):
    """
    Detect the encoding of the given byte string.

    :param byte_str:     The byte sequence to examine.
    :type byte_str:      ``bytes`` or ``bytearray``
    """
    if not isinstance(byte_str, bytearray):
        if not isinstance(byte_str, bytes):
            raise TypeError('Expected object of type bytes or bytearray, got: '
                            '{}'.format(type(byte_str)))
        else:
            byte_str = bytearray(byte_str)
    detector = UniversalDetector()
    detector.feed(byte_str)
    return detector.close()


def detect_all(byte_str):
    """
    Detect all the possible encodings of the given byte string.

    :param byte_str:     The byte sequence to examine.
    :type byte_str:      ``bytes`` or ``bytearray``
    """
    if not isinstance(byte_str, bytearray):
        if not isinstance(byte_str, bytes):
            raise TypeError('Expected object of type bytes or bytearray, got: '
                            '{}'.format(type(byte_str)))
        else:
            byte_str = bytearray(byte_str)

    detector = UniversalDetector()
    detector.feed(byte_str)
    detector.close()

    if detector._input_state == InputState.HIGH_BYTE:
        results = []
        for prober in detector._charset_probers:
            if prober.get_confidence() > detector.MINIMUM_THRESHOLD:
                charset_name = prober.charset_name
                lower_charset_name = prober.charset_name.lower()
                # Use Windows encoding name instead of ISO-8859 if we saw any
                # extra Windows-specific bytes
                if lower_charset_name.startswith('iso-8859'):
                    if detector._has_win_bytes:
                        charset_name = detector.ISO_WIN_MAP.get(lower_charset_name,
                                                            charset_name)
                results.append({
                    'encoding': charset_name,
                    'confidence': prober.get_confidence(),
                    'language': prober.language,
                })
        if len(results) > 0:
            return sorted(results, key=lambda result: -result['confidence'])

    return [detector.result]



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .add_on_options import AddOnOptions
from .admission_controller_options import AdmissionControllerOptions
from .cluster import Cluster
from .cluster_create_options import ClusterCreateOptions
from .cluster_endpoint_config import ClusterEndpointConfig
from .cluster_endpoints import ClusterEndpoints
from .cluster_metadata import ClusterMetadata
from .cluster_migrate_to_native_vcn_details import ClusterMigrateToNativeVcnDetails
from .cluster_migrate_to_native_vcn_status import ClusterMigrateToNativeVcnStatus
from .cluster_options import ClusterOptions
from .cluster_summary import ClusterSummary
from .create_cluster_details import CreateClusterDetails
from .create_cluster_endpoint_config_details import CreateClusterEndpointConfigDetails
from .create_cluster_kubeconfig_content_details import CreateClusterKubeconfigContentDetails
from .create_image_policy_config_details import CreateImagePolicyConfigDetails
from .create_node_pool_details import CreateNodePoolDetails
from .create_node_pool_node_config_details import CreateNodePoolNodeConfigDetails
from .create_node_shape_config_details import CreateNodeShapeConfigDetails
from .image_policy_config import ImagePolicyConfig
from .key_details import KeyDetails
from .key_value import KeyValue
from .kubernetes_network_config import KubernetesNetworkConfig
from .node import Node
from .node_error import NodeError
from .node_pool import NodePool
from .node_pool_node_config_details import NodePoolNodeConfigDetails
from .node_pool_options import NodePoolOptions
from .node_pool_placement_config_details import NodePoolPlacementConfigDetails
from .node_pool_summary import NodePoolSummary
from .node_shape_config import NodeShapeConfig
from .node_source_details import NodeSourceDetails
from .node_source_option import NodeSourceOption
from .node_source_via_image_details import NodeSourceViaImageDetails
from .node_source_via_image_option import NodeSourceViaImageOption
from .update_cluster_details import UpdateClusterDetails
from .update_cluster_endpoint_config_details import UpdateClusterEndpointConfigDetails
from .update_cluster_options_details import UpdateClusterOptionsDetails
from .update_image_policy_config_details import UpdateImagePolicyConfigDetails
from .update_node_pool_details import UpdateNodePoolDetails
from .update_node_pool_node_config_details import UpdateNodePoolNodeConfigDetails
from .update_node_shape_config_details import UpdateNodeShapeConfigDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for container_engine services.
container_engine_type_mapping = {
    "AddOnOptions": AddOnOptions,
    "AdmissionControllerOptions": AdmissionControllerOptions,
    "Cluster": Cluster,
    "ClusterCreateOptions": ClusterCreateOptions,
    "ClusterEndpointConfig": ClusterEndpointConfig,
    "ClusterEndpoints": ClusterEndpoints,
    "ClusterMetadata": ClusterMetadata,
    "ClusterMigrateToNativeVcnDetails": ClusterMigrateToNativeVcnDetails,
    "ClusterMigrateToNativeVcnStatus": ClusterMigrateToNativeVcnStatus,
    "ClusterOptions": ClusterOptions,
    "ClusterSummary": ClusterSummary,
    "CreateClusterDetails": CreateClusterDetails,
    "CreateClusterEndpointConfigDetails": CreateClusterEndpointConfigDetails,
    "CreateClusterKubeconfigContentDetails": CreateClusterKubeconfigContentDetails,
    "CreateImagePolicyConfigDetails": CreateImagePolicyConfigDetails,
    "CreateNodePoolDetails": CreateNodePoolDetails,
    "CreateNodePoolNodeConfigDetails": CreateNodePoolNodeConfigDetails,
    "CreateNodeShapeConfigDetails": CreateNodeShapeConfigDetails,
    "ImagePolicyConfig": ImagePolicyConfig,
    "KeyDetails": KeyDetails,
    "KeyValue": KeyValue,
    "KubernetesNetworkConfig": KubernetesNetworkConfig,
    "Node": Node,
    "NodeError": NodeError,
    "NodePool": NodePool,
    "NodePoolNodeConfigDetails": NodePoolNodeConfigDetails,
    "NodePoolOptions": NodePoolOptions,
    "NodePoolPlacementConfigDetails": NodePoolPlacementConfigDetails,
    "NodePoolSummary": NodePoolSummary,
    "NodeShapeConfig": NodeShapeConfig,
    "NodeSourceDetails": NodeSourceDetails,
    "NodeSourceOption": NodeSourceOption,
    "NodeSourceViaImageDetails": NodeSourceViaImageDetails,
    "NodeSourceViaImageOption": NodeSourceViaImageOption,
    "UpdateClusterDetails": UpdateClusterDetails,
    "UpdateClusterEndpointConfigDetails": UpdateClusterEndpointConfigDetails,
    "UpdateClusterOptionsDetails": UpdateClusterOptionsDetails,
    "UpdateImagePolicyConfigDetails": UpdateImagePolicyConfigDetails,
    "UpdateNodePoolDetails": UpdateNodePoolDetails,
    "UpdateNodePoolNodeConfigDetails": UpdateNodePoolNodeConfigDetails,
    "UpdateNodeShapeConfigDetails": UpdateNodeShapeConfigDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutoLookups(object):
    """
    AutoLookups
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AutoLookups object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param canonical_link:
            The value to assign to the canonical_link property of this AutoLookups.
        :type canonical_link: str

        :param total_count:
            The value to assign to the total_count property of this AutoLookups.
        :type total_count: int

        """
        self.swagger_types = {
            'canonical_link': 'str',
            'total_count': 'int'
        }

        self.attribute_map = {
            'canonical_link': 'canonicalLink',
            'total_count': 'totalCount'
        }

        self._canonical_link = None
        self._total_count = None

    @property
    def canonical_link(self):
        """
        Gets the canonical_link of this AutoLookups.
        The canonical link.


        :return: The canonical_link of this AutoLookups.
        :rtype: str
        """
        return self._canonical_link

    @canonical_link.setter
    def canonical_link(self, canonical_link):
        """
        Sets the canonical_link of this AutoLookups.
        The canonical link.


        :param canonical_link: The canonical_link of this AutoLookups.
        :type: str
        """
        self._canonical_link = canonical_link

    @property
    def total_count(self):
        """
        Gets the total_count of this AutoLookups.
        The total count.


        :return: The total_count of this AutoLookups.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """
        Sets the total_count of this AutoLookups.
        The total count.


        :param total_count: The total_count of this AutoLookups.
        :type: int
        """
        self._total_count = total_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AvailableUpdateSummary(object):
    """
    An update available for a managed instance
    """

    #: A constant which can be used with the update_type property of a AvailableUpdateSummary.
    #: This constant has a value of "SECURITY"
    UPDATE_TYPE_SECURITY = "SECURITY"

    #: A constant which can be used with the update_type property of a AvailableUpdateSummary.
    #: This constant has a value of "BUG"
    UPDATE_TYPE_BUG = "BUG"

    #: A constant which can be used with the update_type property of a AvailableUpdateSummary.
    #: This constant has a value of "ENHANCEMENT"
    UPDATE_TYPE_ENHANCEMENT = "ENHANCEMENT"

    #: A constant which can be used with the update_type property of a AvailableUpdateSummary.
    #: This constant has a value of "OTHER"
    UPDATE_TYPE_OTHER = "OTHER"

    def __init__(self, **kwargs):
        """
        Initializes a new AvailableUpdateSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this AvailableUpdateSummary.
        :type display_name: str

        :param name:
            The value to assign to the name property of this AvailableUpdateSummary.
        :type name: str

        :param update_type:
            The value to assign to the update_type property of this AvailableUpdateSummary.
            Allowed values for this property are: "SECURITY", "BUG", "ENHANCEMENT", "OTHER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type update_type: str

        :param type:
            The value to assign to the type property of this AvailableUpdateSummary.
        :type type: str

        :param installed_version:
            The value to assign to the installed_version property of this AvailableUpdateSummary.
        :type installed_version: str

        :param available_version:
            The value to assign to the available_version property of this AvailableUpdateSummary.
        :type available_version: str

        :param architecture:
            The value to assign to the architecture property of this AvailableUpdateSummary.
        :type architecture: str

        :param errata:
            The value to assign to the errata property of this AvailableUpdateSummary.
        :type errata: list[oci.os_management.models.Id]

        :param related_cves:
            The value to assign to the related_cves property of this AvailableUpdateSummary.
        :type related_cves: list[str]

        :param software_sources:
            The value to assign to the software_sources property of this AvailableUpdateSummary.
        :type software_sources: list[oci.os_management.models.SoftwareSourceId]

        """
        self.swagger_types = {
            'display_name': 'str',
            'name': 'str',
            'update_type': 'str',
            'type': 'str',
            'installed_version': 'str',
            'available_version': 'str',
            'architecture': 'str',
            'errata': 'list[Id]',
            'related_cves': 'list[str]',
            'software_sources': 'list[SoftwareSourceId]'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'name': 'name',
            'update_type': 'updateType',
            'type': 'type',
            'installed_version': 'installedVersion',
            'available_version': 'availableVersion',
            'architecture': 'architecture',
            'errata': 'errata',
            'related_cves': 'relatedCves',
            'software_sources': 'softwareSources'
        }

        self._display_name = None
        self._name = None
        self._update_type = None
        self._type = None
        self._installed_version = None
        self._available_version = None
        self._architecture = None
        self._errata = None
        self._related_cves = None
        self._software_sources = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this AvailableUpdateSummary.
        Package name


        :return: The display_name of this AvailableUpdateSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AvailableUpdateSummary.
        Package name


        :param display_name: The display_name of this AvailableUpdateSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def name(self):
        """
        **[Required]** Gets the name of this AvailableUpdateSummary.
        Unique identifier for the package available for update. NOTE - This is not an OCID


        :return: The name of this AvailableUpdateSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AvailableUpdateSummary.
        Unique identifier for the package available for update. NOTE - This is not an OCID


        :param name: The name of this AvailableUpdateSummary.
        :type: str
        """
        self._name = name

    @property
    def update_type(self):
        """
        Gets the update_type of this AvailableUpdateSummary.
        The purpose of this update.

        Allowed values for this property are: "SECURITY", "BUG", "ENHANCEMENT", "OTHER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The update_type of this AvailableUpdateSummary.
        :rtype: str
        """
        return self._update_type

    @update_type.setter
    def update_type(self, update_type):
        """
        Sets the update_type of this AvailableUpdateSummary.
        The purpose of this update.


        :param update_type: The update_type of this AvailableUpdateSummary.
        :type: str
        """
        allowed_values = ["SECURITY", "BUG", "ENHANCEMENT", "OTHER"]
        if not value_allowed_none_or_none_sentinel(update_type, allowed_values):
            update_type = 'UNKNOWN_ENUM_VALUE'
        self._update_type = update_type

    @property
    def type(self):
        """
        **[Required]** Gets the type of this AvailableUpdateSummary.
        Type of the package


        :return: The type of this AvailableUpdateSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this AvailableUpdateSummary.
        Type of the package


        :param type: The type of this AvailableUpdateSummary.
        :type: str
        """
        self._type = type

    @property
    def installed_version(self):
        """
        **[Required]** Gets the installed_version of this AvailableUpdateSummary.
        Version of the installed package


        :return: The installed_version of this AvailableUpdateSummary.
        :rtype: str
        """
        return self._installed_version

    @installed_version.setter
    def installed_version(self, installed_version):
        """
        Sets the installed_version of this AvailableUpdateSummary.
        Version of the installed package


        :param installed_version: The installed_version of this AvailableUpdateSummary.
        :type: str
        """
        self._installed_version = installed_version

    @property
    def available_version(self):
        """
        **[Required]** Gets the available_version of this AvailableUpdateSummary.
        Version of the package available for update


        :return: The available_version of this AvailableUpdateSummary.
        :rtype: str
        """
        return self._available_version

    @available_version.setter
    def available_version(self, available_version):
        """
        Sets the available_version of this AvailableUpdateSummary.
        Version of the package available for update


        :param available_version: The available_version of this AvailableUpdateSummary.
        :type: str
        """
        self._available_version = available_version

    @property
    def architecture(self):
        """
        Gets the architecture of this AvailableUpdateSummary.
        The architecture for which this package was built


        :return: The architecture of this AvailableUpdateSummary.
        :rtype: str
        """
        return self._architecture

    @architecture.setter
    def architecture(self, architecture):
        """
        Sets the architecture of this AvailableUpdateSummary.
        The architecture for which this package was built


        :param architecture: The architecture of this AvailableUpdateSummary.
        :type: str
        """
        self._architecture = architecture

    @property
    def errata(self):
        """
        Gets the errata of this AvailableUpdateSummary.
        List of errata containing this update


        :return: The errata of this AvailableUpdateSummary.
        :rtype: list[oci.os_management.models.Id]
        """
        return self._errata

    @errata.setter
    def errata(self, errata):
        """
        Sets the errata of this AvailableUpdateSummary.
        List of errata containing this update


        :param errata: The errata of this AvailableUpdateSummary.
        :type: list[oci.os_management.models.Id]
        """
        self._errata = errata

    @property
    def related_cves(self):
        """
        Gets the related_cves of this AvailableUpdateSummary.
        List of CVEs applicable to this erratum


        :return: The related_cves of this AvailableUpdateSummary.
        :rtype: list[str]
        """
        return self._related_cves

    @related_cves.setter
    def related_cves(self, related_cves):
        """
        Sets the related_cves of this AvailableUpdateSummary.
        List of CVEs applicable to this erratum


        :param related_cves: The related_cves of this AvailableUpdateSummary.
        :type: list[str]
        """
        self._related_cves = related_cves

    @property
    def software_sources(self):
        """
        Gets the software_sources of this AvailableUpdateSummary.
        list of software sources that provide the software package


        :return: The software_sources of this AvailableUpdateSummary.
        :rtype: list[oci.os_management.models.SoftwareSourceId]
        """
        return self._software_sources

    @software_sources.setter
    def software_sources(self, software_sources):
        """
        Sets the software_sources of this AvailableUpdateSummary.
        list of software sources that provide the software package


        :param software_sources: The software_sources of this AvailableUpdateSummary.
        :type: list[oci.os_management.models.SoftwareSourceId]
        """
        self._software_sources = software_sources

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AwrDbWaitEventBucketSummary(object):
    """
    A summary of the AWR wait event bucket and waits percentage.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AwrDbWaitEventBucketSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param category:
            The value to assign to the category property of this AwrDbWaitEventBucketSummary.
        :type category: str

        :param percentage:
            The value to assign to the percentage property of this AwrDbWaitEventBucketSummary.
        :type percentage: float

        """
        self.swagger_types = {
            'category': 'str',
            'percentage': 'float'
        }

        self.attribute_map = {
            'category': 'category',
            'percentage': 'percentage'
        }

        self._category = None
        self._percentage = None

    @property
    def category(self):
        """
        **[Required]** Gets the category of this AwrDbWaitEventBucketSummary.
        The name of the wait event frequency category. Normally, it is the upper range of the waits within the AWR wait event bucket.


        :return: The category of this AwrDbWaitEventBucketSummary.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this AwrDbWaitEventBucketSummary.
        The name of the wait event frequency category. Normally, it is the upper range of the waits within the AWR wait event bucket.


        :param category: The category of this AwrDbWaitEventBucketSummary.
        :type: str
        """
        self._category = category

    @property
    def percentage(self):
        """
        **[Required]** Gets the percentage of this AwrDbWaitEventBucketSummary.
        The percentage of waits in a wait event bucket over the total waits of the database.


        :return: The percentage of this AwrDbWaitEventBucketSummary.
        :rtype: float
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage):
        """
        Sets the percentage of this AwrDbWaitEventBucketSummary.
        The percentage of waits in a wait event bucket over the total waits of the database.


        :param percentage: The percentage of this AwrDbWaitEventBucketSummary.
        :type: float
        """
        self._percentage = percentage

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ManagementDashboardTileDetails(object):
    """
    Properties of the dashboard tile representing a saved search.
    Tiles are laid out in a twelve column grid system with (0,0) at upper left corner.
    """

    #: A constant which can be used with the state property of a ManagementDashboardTileDetails.
    #: This constant has a value of "DELETED"
    STATE_DELETED = "DELETED"

    #: A constant which can be used with the state property of a ManagementDashboardTileDetails.
    #: This constant has a value of "UNAUTHORIZED"
    STATE_UNAUTHORIZED = "UNAUTHORIZED"

    #: A constant which can be used with the state property of a ManagementDashboardTileDetails.
    #: This constant has a value of "DEFAULT"
    STATE_DEFAULT = "DEFAULT"

    def __init__(self, **kwargs):
        """
        Initializes a new ManagementDashboardTileDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this ManagementDashboardTileDetails.
        :type display_name: str

        :param saved_search_id:
            The value to assign to the saved_search_id property of this ManagementDashboardTileDetails.
        :type saved_search_id: str

        :param row:
            The value to assign to the row property of this ManagementDashboardTileDetails.
        :type row: int

        :param column:
            The value to assign to the column property of this ManagementDashboardTileDetails.
        :type column: int

        :param height:
            The value to assign to the height property of this ManagementDashboardTileDetails.
        :type height: int

        :param width:
            The value to assign to the width property of this ManagementDashboardTileDetails.
        :type width: int

        :param nls:
            The value to assign to the nls property of this ManagementDashboardTileDetails.
        :type nls: object

        :param ui_config:
            The value to assign to the ui_config property of this ManagementDashboardTileDetails.
        :type ui_config: object

        :param data_config:
            The value to assign to the data_config property of this ManagementDashboardTileDetails.
        :type data_config: list[object]

        :param state:
            The value to assign to the state property of this ManagementDashboardTileDetails.
            Allowed values for this property are: "DELETED", "UNAUTHORIZED", "DEFAULT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type state: str

        :param drilldown_config:
            The value to assign to the drilldown_config property of this ManagementDashboardTileDetails.
        :type drilldown_config: object

        :param parameters_map:
            The value to assign to the parameters_map property of this ManagementDashboardTileDetails.
        :type parameters_map: object

        """
        self.swagger_types = {
            'display_name': 'str',
            'saved_search_id': 'str',
            'row': 'int',
            'column': 'int',
            'height': 'int',
            'width': 'int',
            'nls': 'object',
            'ui_config': 'object',
            'data_config': 'list[object]',
            'state': 'str',
            'drilldown_config': 'object',
            'parameters_map': 'object'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'saved_search_id': 'savedSearchId',
            'row': 'row',
            'column': 'column',
            'height': 'height',
            'width': 'width',
            'nls': 'nls',
            'ui_config': 'uiConfig',
            'data_config': 'dataConfig',
            'state': 'state',
            'drilldown_config': 'drilldownConfig',
            'parameters_map': 'parametersMap'
        }

        self._display_name = None
        self._saved_search_id = None
        self._row = None
        self._column = None
        self._height = None
        self._width = None
        self._nls = None
        self._ui_config = None
        self._data_config = None
        self._state = None
        self._drilldown_config = None
        self._parameters_map = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ManagementDashboardTileDetails.
        Display name of the saved search.


        :return: The display_name of this ManagementDashboardTileDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ManagementDashboardTileDetails.
        Display name of the saved search.


        :param display_name: The display_name of this ManagementDashboardTileDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def saved_search_id(self):
        """
        **[Required]** Gets the saved_search_id of this ManagementDashboardTileDetails.
        ID of the saved search.


        :return: The saved_search_id of this ManagementDashboardTileDetails.
        :rtype: str
        """
        return self._saved_search_id

    @saved_search_id.setter
    def saved_search_id(self, saved_search_id):
        """
        Sets the saved_search_id of this ManagementDashboardTileDetails.
        ID of the saved search.


        :param saved_search_id: The saved_search_id of this ManagementDashboardTileDetails.
        :type: str
        """
        self._saved_search_id = saved_search_id

    @property
    def row(self):
        """
        **[Required]** Gets the row of this ManagementDashboardTileDetails.
        Tile's row number.


        :return: The row of this ManagementDashboardTileDetails.
        :rtype: int
        """
        return self._row

    @row.setter
    def row(self, row):
        """
        Sets the row of this ManagementDashboardTileDetails.
        Tile's row number.


        :param row: The row of this ManagementDashboardTileDetails.
        :type: int
        """
        self._row = row

    @property
    def column(self):
        """
        **[Required]** Gets the column of this ManagementDashboardTileDetails.
        Tile's column number.


        :return: The column of this ManagementDashboardTileDetails.
        :rtype: int
        """
        return self._column

    @column.setter
    def column(self, column):
        """
        Sets the column of this ManagementDashboardTileDetails.
        Tile's column number.


        :param column: The column of this ManagementDashboardTileDetails.
        :type: int
        """
        self._column = column

    @property
    def height(self):
        """
        **[Required]** Gets the height of this ManagementDashboardTileDetails.
        The number of rows the tile occupies.


        :return: The height of this ManagementDashboardTileDetails.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height of this ManagementDashboardTileDetails.
        The number of rows the tile occupies.


        :param height: The height of this ManagementDashboardTileDetails.
        :type: int
        """
        self._height = height

    @property
    def width(self):
        """
        **[Required]** Gets the width of this ManagementDashboardTileDetails.
        The number of columns the tile occupies.


        :return: The width of this ManagementDashboardTileDetails.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width of this ManagementDashboardTileDetails.
        The number of columns the tile occupies.


        :param width: The width of this ManagementDashboardTileDetails.
        :type: int
        """
        self._width = width

    @property
    def nls(self):
        """
        **[Required]** Gets the nls of this ManagementDashboardTileDetails.
        JSON that contains internationalization options.


        :return: The nls of this ManagementDashboardTileDetails.
        :rtype: object
        """
        return self._nls

    @nls.setter
    def nls(self, nls):
        """
        Sets the nls of this ManagementDashboardTileDetails.
        JSON that contains internationalization options.


        :param nls: The nls of this ManagementDashboardTileDetails.
        :type: object
        """
        self._nls = nls

    @property
    def ui_config(self):
        """
        **[Required]** Gets the ui_config of this ManagementDashboardTileDetails.
        JSON that contains user interface options.


        :return: The ui_config of this ManagementDashboardTileDetails.
        :rtype: object
        """
        return self._ui_config

    @ui_config.setter
    def ui_config(self, ui_config):
        """
        Sets the ui_config of this ManagementDashboardTileDetails.
        JSON that contains user interface options.


        :param ui_config: The ui_config of this ManagementDashboardTileDetails.
        :type: object
        """
        self._ui_config = ui_config

    @property
    def data_config(self):
        """
        **[Required]** Gets the data_config of this ManagementDashboardTileDetails.
        Array of JSON that contain data source options.


        :return: The data_config of this ManagementDashboardTileDetails.
        :rtype: list[object]
        """
        return self._data_config

    @data_config.setter
    def data_config(self, data_config):
        """
        Sets the data_config of this ManagementDashboardTileDetails.
        Array of JSON that contain data source options.


        :param data_config: The data_config of this ManagementDashboardTileDetails.
        :type: list[object]
        """
        self._data_config = data_config

    @property
    def state(self):
        """
        **[Required]** Gets the state of this ManagementDashboardTileDetails.
        Current state of the saved search.

        Allowed values for this property are: "DELETED", "UNAUTHORIZED", "DEFAULT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The state of this ManagementDashboardTileDetails.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ManagementDashboardTileDetails.
        Current state of the saved search.


        :param state: The state of this ManagementDashboardTileDetails.
        :type: str
        """
        allowed_values = ["DELETED", "UNAUTHORIZED", "DEFAULT"]
        if not value_allowed_none_or_none_sentinel(state, allowed_values):
            state = 'UNKNOWN_ENUM_VALUE'
        self._state = state

    @property
    def drilldown_config(self):
        """
        **[Required]** Gets the drilldown_config of this ManagementDashboardTileDetails.
        Drill-down configuration to define the destination of a drill-down action.


        :return: The drilldown_config of this ManagementDashboardTileDetails.
        :rtype: object
        """
        return self._drilldown_config

    @drilldown_config.setter
    def drilldown_config(self, drilldown_config):
        """
        Sets the drilldown_config of this ManagementDashboardTileDetails.
        Drill-down configuration to define the destination of a drill-down action.


        :param drilldown_config: The drilldown_config of this ManagementDashboardTileDetails.
        :type: object
        """
        self._drilldown_config = drilldown_config

    @property
    def parameters_map(self):
        """
        Gets the parameters_map of this ManagementDashboardTileDetails.
        Specifies the saved search parameters values


        :return: The parameters_map of this ManagementDashboardTileDetails.
        :rtype: object
        """
        return self._parameters_map

    @parameters_map.setter
    def parameters_map(self, parameters_map):
        """
        Sets the parameters_map of this ManagementDashboardTileDetails.
        Specifies the saved search parameters values


        :param parameters_map: The parameters_map of this ManagementDashboardTileDetails.
        :type: object
        """
        self._parameters_map = parameters_map

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateJobDetails(object):
    """
    Properties used to create a job.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateJobDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateJobDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateJobDetails.
        :type description: str

        :param schedule_cron_expression:
            The value to assign to the schedule_cron_expression property of this CreateJobDetails.
        :type schedule_cron_expression: str

        :param time_schedule_begin:
            The value to assign to the time_schedule_begin property of this CreateJobDetails.
        :type time_schedule_begin: datetime

        :param time_schedule_end:
            The value to assign to the time_schedule_end property of this CreateJobDetails.
        :type time_schedule_end: datetime

        :param connection_key:
            The value to assign to the connection_key property of this CreateJobDetails.
        :type connection_key: str

        :param job_definition_key:
            The value to assign to the job_definition_key property of this CreateJobDetails.
        :type job_definition_key: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'schedule_cron_expression': 'str',
            'time_schedule_begin': 'datetime',
            'time_schedule_end': 'datetime',
            'connection_key': 'str',
            'job_definition_key': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'schedule_cron_expression': 'scheduleCronExpression',
            'time_schedule_begin': 'timeScheduleBegin',
            'time_schedule_end': 'timeScheduleEnd',
            'connection_key': 'connectionKey',
            'job_definition_key': 'jobDefinitionKey'
        }

        self._display_name = None
        self._description = None
        self._schedule_cron_expression = None
        self._time_schedule_begin = None
        self._time_schedule_end = None
        self._connection_key = None
        self._job_definition_key = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateJobDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this CreateJobDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateJobDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CreateJobDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateJobDetails.
        Detailed description of the job.


        :return: The description of this CreateJobDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateJobDetails.
        Detailed description of the job.


        :param description: The description of this CreateJobDetails.
        :type: str
        """
        self._description = description

    @property
    def schedule_cron_expression(self):
        """
        Gets the schedule_cron_expression of this CreateJobDetails.
        Schedule specified in the cron expression format that has seven fields for second, minute, hour, day-of-month, month, day-of-week, year.
        It can also include special characters like * for all and ? for any. There are also pre-defined schedules that can be specified using
        special strings. For example, @hourly will run the job every hour.


        :return: The schedule_cron_expression of this CreateJobDetails.
        :rtype: str
        """
        return self._schedule_cron_expression

    @schedule_cron_expression.setter
    def schedule_cron_expression(self, schedule_cron_expression):
        """
        Sets the schedule_cron_expression of this CreateJobDetails.
        Schedule specified in the cron expression format that has seven fields for second, minute, hour, day-of-month, month, day-of-week, year.
        It can also include special characters like * for all and ? for any. There are also pre-defined schedules that can be specified using
        special strings. For example, @hourly will run the job every hour.


        :param schedule_cron_expression: The schedule_cron_expression of this CreateJobDetails.
        :type: str
        """
        self._schedule_cron_expression = schedule_cron_expression

    @property
    def time_schedule_begin(self):
        """
        Gets the time_schedule_begin of this CreateJobDetails.
        Date that the schedule should be operational. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_schedule_begin of this CreateJobDetails.
        :rtype: datetime
        """
        return self._time_schedule_begin

    @time_schedule_begin.setter
    def time_schedule_begin(self, time_schedule_begin):
        """
        Sets the time_schedule_begin of this CreateJobDetails.
        Date that the schedule should be operational. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_schedule_begin: The time_schedule_begin of this CreateJobDetails.
        :type: datetime
        """
        self._time_schedule_begin = time_schedule_begin

    @property
    def time_schedule_end(self):
        """
        Gets the time_schedule_end of this CreateJobDetails.
        Date that the schedule should end from being operational. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_schedule_end of this CreateJobDetails.
        :rtype: datetime
        """
        return self._time_schedule_end

    @time_schedule_end.setter
    def time_schedule_end(self, time_schedule_end):
        """
        Sets the time_schedule_end of this CreateJobDetails.
        Date that the schedule should end from being operational. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_schedule_end: The time_schedule_end of this CreateJobDetails.
        :type: datetime
        """
        self._time_schedule_end = time_schedule_end

    @property
    def connection_key(self):
        """
        Gets the connection_key of this CreateJobDetails.
        The key of the connection used by the job. This connection will override the default connection specified in
        the associated job definition. All executions will use this connection.


        :return: The connection_key of this CreateJobDetails.
        :rtype: str
        """
        return self._connection_key

    @connection_key.setter
    def connection_key(self, connection_key):
        """
        Sets the connection_key of this CreateJobDetails.
        The key of the connection used by the job. This connection will override the default connection specified in
        the associated job definition. All executions will use this connection.


        :param connection_key: The connection_key of this CreateJobDetails.
        :type: str
        """
        self._connection_key = connection_key

    @property
    def job_definition_key(self):
        """
        **[Required]** Gets the job_definition_key of this CreateJobDetails.
        The unique key of the job definition that defined the scope of this job.


        :return: The job_definition_key of this CreateJobDetails.
        :rtype: str
        """
        return self._job_definition_key

    @job_definition_key.setter
    def job_definition_key(self, job_definition_key):
        """
        Sets the job_definition_key of this CreateJobDetails.
        The unique key of the job definition that defined the scope of this job.


        :param job_definition_key: The job_definition_key of this CreateJobDetails.
        :type: str
        """
        self._job_definition_key = job_definition_key

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EnableDatabaseManagementDetails(object):
    """
    Data to enable the Database Management service for the database.
    """

    #: A constant which can be used with the management_type property of a EnableDatabaseManagementDetails.
    #: This constant has a value of "BASIC"
    MANAGEMENT_TYPE_BASIC = "BASIC"

    #: A constant which can be used with the management_type property of a EnableDatabaseManagementDetails.
    #: This constant has a value of "ADVANCED"
    MANAGEMENT_TYPE_ADVANCED = "ADVANCED"

    def __init__(self, **kwargs):
        """
        Initializes a new EnableDatabaseManagementDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param credential_details:
            The value to assign to the credential_details property of this EnableDatabaseManagementDetails.
        :type credential_details: oci.database.models.DatabaseCredentialDetails

        :param private_end_point_id:
            The value to assign to the private_end_point_id property of this EnableDatabaseManagementDetails.
        :type private_end_point_id: str

        :param management_type:
            The value to assign to the management_type property of this EnableDatabaseManagementDetails.
            Allowed values for this property are: "BASIC", "ADVANCED"
        :type management_type: str

        :param service_name:
            The value to assign to the service_name property of this EnableDatabaseManagementDetails.
        :type service_name: str

        """
        self.swagger_types = {
            'credential_details': 'DatabaseCredentialDetails',
            'private_end_point_id': 'str',
            'management_type': 'str',
            'service_name': 'str'
        }

        self.attribute_map = {
            'credential_details': 'credentialDetails',
            'private_end_point_id': 'privateEndPointId',
            'management_type': 'managementType',
            'service_name': 'serviceName'
        }

        self._credential_details = None
        self._private_end_point_id = None
        self._management_type = None
        self._service_name = None

    @property
    def credential_details(self):
        """
        **[Required]** Gets the credential_details of this EnableDatabaseManagementDetails.

        :return: The credential_details of this EnableDatabaseManagementDetails.
        :rtype: oci.database.models.DatabaseCredentialDetails
        """
        return self._credential_details

    @credential_details.setter
    def credential_details(self, credential_details):
        """
        Sets the credential_details of this EnableDatabaseManagementDetails.

        :param credential_details: The credential_details of this EnableDatabaseManagementDetails.
        :type: oci.database.models.DatabaseCredentialDetails
        """
        self._credential_details = credential_details

    @property
    def private_end_point_id(self):
        """
        **[Required]** Gets the private_end_point_id of this EnableDatabaseManagementDetails.
        The `OCID`__ of the private endpoint.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The private_end_point_id of this EnableDatabaseManagementDetails.
        :rtype: str
        """
        return self._private_end_point_id

    @private_end_point_id.setter
    def private_end_point_id(self, private_end_point_id):
        """
        Sets the private_end_point_id of this EnableDatabaseManagementDetails.
        The `OCID`__ of the private endpoint.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param private_end_point_id: The private_end_point_id of this EnableDatabaseManagementDetails.
        :type: str
        """
        self._private_end_point_id = private_end_point_id

    @property
    def management_type(self):
        """
        Gets the management_type of this EnableDatabaseManagementDetails.
        The Database Management type.

        Allowed values for this property are: "BASIC", "ADVANCED"


        :return: The management_type of this EnableDatabaseManagementDetails.
        :rtype: str
        """
        return self._management_type

    @management_type.setter
    def management_type(self, management_type):
        """
        Sets the management_type of this EnableDatabaseManagementDetails.
        The Database Management type.


        :param management_type: The management_type of this EnableDatabaseManagementDetails.
        :type: str
        """
        allowed_values = ["BASIC", "ADVANCED"]
        if not value_allowed_none_or_none_sentinel(management_type, allowed_values):
            raise ValueError(
                "Invalid value for `management_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._management_type = management_type

    @property
    def service_name(self):
        """
        **[Required]** Gets the service_name of this EnableDatabaseManagementDetails.
        The name of the Oracle Database service that will be used to connect to the database.


        :return: The service_name of this EnableDatabaseManagementDetails.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this EnableDatabaseManagementDetails.
        The name of the Oracle Database service that will be used to connect to the database.


        :param service_name: The service_name of this EnableDatabaseManagementDetails.
        :type: str
        """
        self._service_name = service_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BodyValidationRequestPolicy(object):
    """
    Validate the payload body of the incoming API requests on a specific route.
    """

    #: A constant which can be used with the validation_mode property of a BodyValidationRequestPolicy.
    #: This constant has a value of "ENFORCING"
    VALIDATION_MODE_ENFORCING = "ENFORCING"

    #: A constant which can be used with the validation_mode property of a BodyValidationRequestPolicy.
    #: This constant has a value of "PERMISSIVE"
    VALIDATION_MODE_PERMISSIVE = "PERMISSIVE"

    #: A constant which can be used with the validation_mode property of a BodyValidationRequestPolicy.
    #: This constant has a value of "DISABLED"
    VALIDATION_MODE_DISABLED = "DISABLED"

    def __init__(self, **kwargs):
        """
        Initializes a new BodyValidationRequestPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param required:
            The value to assign to the required property of this BodyValidationRequestPolicy.
        :type required: bool

        :param content:
            The value to assign to the content property of this BodyValidationRequestPolicy.
        :type content: dict(str, ContentValidation)

        :param validation_mode:
            The value to assign to the validation_mode property of this BodyValidationRequestPolicy.
            Allowed values for this property are: "ENFORCING", "PERMISSIVE", "DISABLED"
        :type validation_mode: str

        """
        self.swagger_types = {
            'required': 'bool',
            'content': 'dict(str, ContentValidation)',
            'validation_mode': 'str'
        }

        self.attribute_map = {
            'required': 'required',
            'content': 'content',
            'validation_mode': 'validationMode'
        }

        self._required = None
        self._content = None
        self._validation_mode = None

    @property
    def required(self):
        """
        Gets the required of this BodyValidationRequestPolicy.
        Determines if the request body is required in the request.


        :return: The required of this BodyValidationRequestPolicy.
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """
        Sets the required of this BodyValidationRequestPolicy.
        Determines if the request body is required in the request.


        :param required: The required of this BodyValidationRequestPolicy.
        :type: bool
        """
        self._required = required

    @property
    def content(self):
        """
        **[Required]** Gets the content of this BodyValidationRequestPolicy.
        The content of the request body. The key is a `media type range`__
        subset restricted to the following schema

            key ::= (
                  / (  \"*\" \"/\" \"*\" )
                  / ( type \"/\" \"*\" )
                  / ( type \"/\" subtype )
                  )

        For requests that match multiple keys, only the most specific key is applicable.
        e.g. `text/plain` overrides `text/*`

        __ https://tools.ietf.org/html/rfc7231#appendix-D


        :return: The content of this BodyValidationRequestPolicy.
        :rtype: dict(str, ContentValidation)
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this BodyValidationRequestPolicy.
        The content of the request body. The key is a `media type range`__
        subset restricted to the following schema

            key ::= (
                  / (  \"*\" \"/\" \"*\" )
                  / ( type \"/\" \"*\" )
                  / ( type \"/\" subtype )
                  )

        For requests that match multiple keys, only the most specific key is applicable.
        e.g. `text/plain` overrides `text/*`

        __ https://tools.ietf.org/html/rfc7231#appendix-D


        :param content: The content of this BodyValidationRequestPolicy.
        :type: dict(str, ContentValidation)
        """
        self._content = content

    @property
    def validation_mode(self):
        """
        Gets the validation_mode of this BodyValidationRequestPolicy.
        Validation behavior mode.

        In `ENFORCING` mode, upon a validation failure, the request will be rejected with a 4xx response
        and not sent to the backend.

        In `PERMISSIVE` mode, the result of the validation will be exposed as metrics while the request
        will follow the normal path.

        `DISABLED` type turns the validation off.

        Allowed values for this property are: "ENFORCING", "PERMISSIVE", "DISABLED"


        :return: The validation_mode of this BodyValidationRequestPolicy.
        :rtype: str
        """
        return self._validation_mode

    @validation_mode.setter
    def validation_mode(self, validation_mode):
        """
        Sets the validation_mode of this BodyValidationRequestPolicy.
        Validation behavior mode.

        In `ENFORCING` mode, upon a validation failure, the request will be rejected with a 4xx response
        and not sent to the backend.

        In `PERMISSIVE` mode, the result of the validation will be exposed as metrics while the request
        will follow the normal path.

        `DISABLED` type turns the validation off.


        :param validation_mode: The validation_mode of this BodyValidationRequestPolicy.
        :type: str
        """
        allowed_values = ["ENFORCING", "PERMISSIVE", "DISABLED"]
        if not value_allowed_none_or_none_sentinel(validation_mode, allowed_values):
            raise ValueError(
                "Invalid value for `validation_mode`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._validation_mode = validation_mode

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StatusSummary(object):
    """
    StatusSummary
    """

    def __init__(self, **kwargs):
        """
        Initializes a new StatusSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param chunks_processed:
            The value to assign to the chunks_processed property of this StatusSummary.
        :type chunks_processed: int

        :param failure_details:
            The value to assign to the failure_details property of this StatusSummary.
        :type failure_details: str

        :param filename:
            The value to assign to the filename property of this StatusSummary.
        :type filename: str

        :param status:
            The value to assign to the status property of this StatusSummary.
        :type status: str

        :param total_chunks:
            The value to assign to the total_chunks property of this StatusSummary.
        :type total_chunks: int

        """
        self.swagger_types = {
            'chunks_processed': 'int',
            'failure_details': 'str',
            'filename': 'str',
            'status': 'str',
            'total_chunks': 'int'
        }

        self.attribute_map = {
            'chunks_processed': 'chunksProcessed',
            'failure_details': 'failureDetails',
            'filename': 'filename',
            'status': 'status',
            'total_chunks': 'totalChunks'
        }

        self._chunks_processed = None
        self._failure_details = None
        self._filename = None
        self._status = None
        self._total_chunks = None

    @property
    def chunks_processed(self):
        """
        Gets the chunks_processed of this StatusSummary.
        The number of chunks processed.


        :return: The chunks_processed of this StatusSummary.
        :rtype: int
        """
        return self._chunks_processed

    @chunks_processed.setter
    def chunks_processed(self, chunks_processed):
        """
        Sets the chunks_processed of this StatusSummary.
        The number of chunks processed.


        :param chunks_processed: The chunks_processed of this StatusSummary.
        :type: int
        """
        self._chunks_processed = chunks_processed

    @property
    def failure_details(self):
        """
        Gets the failure_details of this StatusSummary.
        The failure details, if any.


        :return: The failure_details of this StatusSummary.
        :rtype: str
        """
        return self._failure_details

    @failure_details.setter
    def failure_details(self, failure_details):
        """
        Sets the failure_details of this StatusSummary.
        The failure details, if any.


        :param failure_details: The failure_details of this StatusSummary.
        :type: str
        """
        self._failure_details = failure_details

    @property
    def filename(self):
        """
        Gets the filename of this StatusSummary.
        The filename.


        :return: The filename of this StatusSummary.
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """
        Sets the filename of this StatusSummary.
        The filename.


        :param filename: The filename of this StatusSummary.
        :type: str
        """
        self._filename = filename

    @property
    def status(self):
        """
        Gets the status of this StatusSummary.
        The status.


        :return: The status of this StatusSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this StatusSummary.
        The status.


        :param status: The status of this StatusSummary.
        :type: str
        """
        self._status = status

    @property
    def total_chunks(self):
        """
        Gets the total_chunks of this StatusSummary.
        The total number of chunks.


        :return: The total_chunks of this StatusSummary.
        :rtype: int
        """
        return self._total_chunks

    @total_chunks.setter
    def total_chunks(self, total_chunks):
        """
        Sets the total_chunks of this StatusSummary.
        The total number of chunks.


        :param total_chunks: The total_chunks of this StatusSummary.
        :type: int
        """
        self._total_chunks = total_chunks

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OcpuAllocationNumberParam(object):
    """
    OCPU allocation parameter
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OcpuAllocationNumberParam object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ocpu_allocation_number:
            The value to assign to the ocpu_allocation_number property of this OcpuAllocationNumberParam.
        :type ocpu_allocation_number: float

        """
        self.swagger_types = {
            'ocpu_allocation_number': 'float'
        }

        self.attribute_map = {
            'ocpu_allocation_number': 'ocpuAllocationNumber'
        }

        self._ocpu_allocation_number = None

    @property
    def ocpu_allocation_number(self):
        """
        **[Required]** Gets the ocpu_allocation_number of this OcpuAllocationNumberParam.
        Number of OCPU allocation


        :return: The ocpu_allocation_number of this OcpuAllocationNumberParam.
        :rtype: float
        """
        return self._ocpu_allocation_number

    @ocpu_allocation_number.setter
    def ocpu_allocation_number(self, ocpu_allocation_number):
        """
        Sets the ocpu_allocation_number of this OcpuAllocationNumberParam.
        Number of OCPU allocation


        :param ocpu_allocation_number: The ocpu_allocation_number of this OcpuAllocationNumberParam.
        :type: float
        """
        self._ocpu_allocation_number = ocpu_allocation_number

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .host_performance_metric_group import HostPerformanceMetricGroup
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostNetworkActivitySummary(HostPerformanceMetricGroup):
    """
    Network Activity Summary metric for the host
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HostNetworkActivitySummary object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.HostNetworkActivitySummary.metric_name` attribute
        of this class is ``HOST_NETWORK_ACTIVITY_SUMMARY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this HostNetworkActivitySummary.
            Allowed values for this property are: "HOST_CPU_USAGE", "HOST_MEMORY_USAGE", "HOST_NETWORK_ACTIVITY_SUMMARY"
        :type metric_name: str

        :param time_collected:
            The value to assign to the time_collected property of this HostNetworkActivitySummary.
        :type time_collected: datetime

        :param all_network_read_in_mbps:
            The value to assign to the all_network_read_in_mbps property of this HostNetworkActivitySummary.
        :type all_network_read_in_mbps: float

        :param all_network_write_in_mbps:
            The value to assign to the all_network_write_in_mbps property of this HostNetworkActivitySummary.
        :type all_network_write_in_mbps: float

        :param all_network_io_in_mbps:
            The value to assign to the all_network_io_in_mbps property of this HostNetworkActivitySummary.
        :type all_network_io_in_mbps: float

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_collected': 'datetime',
            'all_network_read_in_mbps': 'float',
            'all_network_write_in_mbps': 'float',
            'all_network_io_in_mbps': 'float'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_collected': 'timeCollected',
            'all_network_read_in_mbps': 'allNetworkReadInMbps',
            'all_network_write_in_mbps': 'allNetworkWriteInMbps',
            'all_network_io_in_mbps': 'allNetworkIoInMbps'
        }

        self._metric_name = None
        self._time_collected = None
        self._all_network_read_in_mbps = None
        self._all_network_write_in_mbps = None
        self._all_network_io_in_mbps = None
        self._metric_name = 'HOST_NETWORK_ACTIVITY_SUMMARY'

    @property
    def all_network_read_in_mbps(self):
        """
        Gets the all_network_read_in_mbps of this HostNetworkActivitySummary.
        All network interfaces read rate in Mbps


        :return: The all_network_read_in_mbps of this HostNetworkActivitySummary.
        :rtype: float
        """
        return self._all_network_read_in_mbps

    @all_network_read_in_mbps.setter
    def all_network_read_in_mbps(self, all_network_read_in_mbps):
        """
        Sets the all_network_read_in_mbps of this HostNetworkActivitySummary.
        All network interfaces read rate in Mbps


        :param all_network_read_in_mbps: The all_network_read_in_mbps of this HostNetworkActivitySummary.
        :type: float
        """
        self._all_network_read_in_mbps = all_network_read_in_mbps

    @property
    def all_network_write_in_mbps(self):
        """
        Gets the all_network_write_in_mbps of this HostNetworkActivitySummary.
        All network interfaces write rate in Mbps


        :return: The all_network_write_in_mbps of this HostNetworkActivitySummary.
        :rtype: float
        """
        return self._all_network_write_in_mbps

    @all_network_write_in_mbps.setter
    def all_network_write_in_mbps(self, all_network_write_in_mbps):
        """
        Sets the all_network_write_in_mbps of this HostNetworkActivitySummary.
        All network interfaces write rate in Mbps


        :param all_network_write_in_mbps: The all_network_write_in_mbps of this HostNetworkActivitySummary.
        :type: float
        """
        self._all_network_write_in_mbps = all_network_write_in_mbps

    @property
    def all_network_io_in_mbps(self):
        """
        Gets the all_network_io_in_mbps of this HostNetworkActivitySummary.
        All network interfaces IO rate in Mbps


        :return: The all_network_io_in_mbps of this HostNetworkActivitySummary.
        :rtype: float
        """
        return self._all_network_io_in_mbps

    @all_network_io_in_mbps.setter
    def all_network_io_in_mbps(self, all_network_io_in_mbps):
        """
        Sets the all_network_io_in_mbps of this HostNetworkActivitySummary.
        All network interfaces IO rate in Mbps


        :param all_network_io_in_mbps: The all_network_io_in_mbps of this HostNetworkActivitySummary.
        :type: float
        """
        self._all_network_io_in_mbps = all_network_io_in_mbps

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlStatistics(object):
    """
    Performance statistics for the SQL.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlStatistics object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_time_in_sec:
            The value to assign to the database_time_in_sec property of this SqlStatistics.
        :type database_time_in_sec: float

        :param executions_per_hour:
            The value to assign to the executions_per_hour property of this SqlStatistics.
        :type executions_per_hour: float

        :param executions_count:
            The value to assign to the executions_count property of this SqlStatistics.
        :type executions_count: int

        :param cpu_time_in_sec:
            The value to assign to the cpu_time_in_sec property of this SqlStatistics.
        :type cpu_time_in_sec: float

        :param io_time_in_sec:
            The value to assign to the io_time_in_sec property of this SqlStatistics.
        :type io_time_in_sec: float

        :param inefficient_wait_time_in_sec:
            The value to assign to the inefficient_wait_time_in_sec property of this SqlStatistics.
        :type inefficient_wait_time_in_sec: float

        :param response_time_in_sec:
            The value to assign to the response_time_in_sec property of this SqlStatistics.
        :type response_time_in_sec: float

        :param plan_count:
            The value to assign to the plan_count property of this SqlStatistics.
        :type plan_count: int

        :param variability:
            The value to assign to the variability property of this SqlStatistics.
        :type variability: float

        :param average_active_sessions:
            The value to assign to the average_active_sessions property of this SqlStatistics.
        :type average_active_sessions: float

        :param database_time_pct:
            The value to assign to the database_time_pct property of this SqlStatistics.
        :type database_time_pct: float

        :param inefficiency_in_pct:
            The value to assign to the inefficiency_in_pct property of this SqlStatistics.
        :type inefficiency_in_pct: float

        :param change_in_cpu_time_in_pct:
            The value to assign to the change_in_cpu_time_in_pct property of this SqlStatistics.
        :type change_in_cpu_time_in_pct: float

        :param change_in_io_time_in_pct:
            The value to assign to the change_in_io_time_in_pct property of this SqlStatistics.
        :type change_in_io_time_in_pct: float

        :param change_in_inefficient_wait_time_in_pct:
            The value to assign to the change_in_inefficient_wait_time_in_pct property of this SqlStatistics.
        :type change_in_inefficient_wait_time_in_pct: float

        :param change_in_response_time_in_pct:
            The value to assign to the change_in_response_time_in_pct property of this SqlStatistics.
        :type change_in_response_time_in_pct: float

        :param change_in_average_active_sessions_in_pct:
            The value to assign to the change_in_average_active_sessions_in_pct property of this SqlStatistics.
        :type change_in_average_active_sessions_in_pct: float

        :param change_in_executions_per_hour_in_pct:
            The value to assign to the change_in_executions_per_hour_in_pct property of this SqlStatistics.
        :type change_in_executions_per_hour_in_pct: float

        :param change_in_inefficiency_in_pct:
            The value to assign to the change_in_inefficiency_in_pct property of this SqlStatistics.
        :type change_in_inefficiency_in_pct: float

        """
        self.swagger_types = {
            'database_time_in_sec': 'float',
            'executions_per_hour': 'float',
            'executions_count': 'int',
            'cpu_time_in_sec': 'float',
            'io_time_in_sec': 'float',
            'inefficient_wait_time_in_sec': 'float',
            'response_time_in_sec': 'float',
            'plan_count': 'int',
            'variability': 'float',
            'average_active_sessions': 'float',
            'database_time_pct': 'float',
            'inefficiency_in_pct': 'float',
            'change_in_cpu_time_in_pct': 'float',
            'change_in_io_time_in_pct': 'float',
            'change_in_inefficient_wait_time_in_pct': 'float',
            'change_in_response_time_in_pct': 'float',
            'change_in_average_active_sessions_in_pct': 'float',
            'change_in_executions_per_hour_in_pct': 'float',
            'change_in_inefficiency_in_pct': 'float'
        }

        self.attribute_map = {
            'database_time_in_sec': 'databaseTimeInSec',
            'executions_per_hour': 'executionsPerHour',
            'executions_count': 'executionsCount',
            'cpu_time_in_sec': 'cpuTimeInSec',
            'io_time_in_sec': 'ioTimeInSec',
            'inefficient_wait_time_in_sec': 'inefficientWaitTimeInSec',
            'response_time_in_sec': 'responseTimeInSec',
            'plan_count': 'planCount',
            'variability': 'variability',
            'average_active_sessions': 'averageActiveSessions',
            'database_time_pct': 'databaseTimePct',
            'inefficiency_in_pct': 'inefficiencyInPct',
            'change_in_cpu_time_in_pct': 'changeInCpuTimeInPct',
            'change_in_io_time_in_pct': 'changeInIoTimeInPct',
            'change_in_inefficient_wait_time_in_pct': 'changeInInefficientWaitTimeInPct',
            'change_in_response_time_in_pct': 'changeInResponseTimeInPct',
            'change_in_average_active_sessions_in_pct': 'changeInAverageActiveSessionsInPct',
            'change_in_executions_per_hour_in_pct': 'changeInExecutionsPerHourInPct',
            'change_in_inefficiency_in_pct': 'changeInInefficiencyInPct'
        }

        self._database_time_in_sec = None
        self._executions_per_hour = None
        self._executions_count = None
        self._cpu_time_in_sec = None
        self._io_time_in_sec = None
        self._inefficient_wait_time_in_sec = None
        self._response_time_in_sec = None
        self._plan_count = None
        self._variability = None
        self._average_active_sessions = None
        self._database_time_pct = None
        self._inefficiency_in_pct = None
        self._change_in_cpu_time_in_pct = None
        self._change_in_io_time_in_pct = None
        self._change_in_inefficient_wait_time_in_pct = None
        self._change_in_response_time_in_pct = None
        self._change_in_average_active_sessions_in_pct = None
        self._change_in_executions_per_hour_in_pct = None
        self._change_in_inefficiency_in_pct = None

    @property
    def database_time_in_sec(self):
        """
        **[Required]** Gets the database_time_in_sec of this SqlStatistics.
        Database Time in seconds


        :return: The database_time_in_sec of this SqlStatistics.
        :rtype: float
        """
        return self._database_time_in_sec

    @database_time_in_sec.setter
    def database_time_in_sec(self, database_time_in_sec):
        """
        Sets the database_time_in_sec of this SqlStatistics.
        Database Time in seconds


        :param database_time_in_sec: The database_time_in_sec of this SqlStatistics.
        :type: float
        """
        self._database_time_in_sec = database_time_in_sec

    @property
    def executions_per_hour(self):
        """
        **[Required]** Gets the executions_per_hour of this SqlStatistics.
        Number of executions per hour


        :return: The executions_per_hour of this SqlStatistics.
        :rtype: float
        """
        return self._executions_per_hour

    @executions_per_hour.setter
    def executions_per_hour(self, executions_per_hour):
        """
        Sets the executions_per_hour of this SqlStatistics.
        Number of executions per hour


        :param executions_per_hour: The executions_per_hour of this SqlStatistics.
        :type: float
        """
        self._executions_per_hour = executions_per_hour

    @property
    def executions_count(self):
        """
        **[Required]** Gets the executions_count of this SqlStatistics.
        Total number of executions


        :return: The executions_count of this SqlStatistics.
        :rtype: int
        """
        return self._executions_count

    @executions_count.setter
    def executions_count(self, executions_count):
        """
        Sets the executions_count of this SqlStatistics.
        Total number of executions


        :param executions_count: The executions_count of this SqlStatistics.
        :type: int
        """
        self._executions_count = executions_count

    @property
    def cpu_time_in_sec(self):
        """
        **[Required]** Gets the cpu_time_in_sec of this SqlStatistics.
        CPU Time in seconds


        :return: The cpu_time_in_sec of this SqlStatistics.
        :rtype: float
        """
        return self._cpu_time_in_sec

    @cpu_time_in_sec.setter
    def cpu_time_in_sec(self, cpu_time_in_sec):
        """
        Sets the cpu_time_in_sec of this SqlStatistics.
        CPU Time in seconds


        :param cpu_time_in_sec: The cpu_time_in_sec of this SqlStatistics.
        :type: float
        """
        self._cpu_time_in_sec = cpu_time_in_sec

    @property
    def io_time_in_sec(self):
        """
        **[Required]** Gets the io_time_in_sec of this SqlStatistics.
        I/O Time in seconds


        :return: The io_time_in_sec of this SqlStatistics.
        :rtype: float
        """
        return self._io_time_in_sec

    @io_time_in_sec.setter
    def io_time_in_sec(self, io_time_in_sec):
        """
        Sets the io_time_in_sec of this SqlStatistics.
        I/O Time in seconds


        :param io_time_in_sec: The io_time_in_sec of this SqlStatistics.
        :type: float
        """
        self._io_time_in_sec = io_time_in_sec

    @property
    def inefficient_wait_time_in_sec(self):
        """
        **[Required]** Gets the inefficient_wait_time_in_sec of this SqlStatistics.
        Inefficient Wait Time in seconds


        :return: The inefficient_wait_time_in_sec of this SqlStatistics.
        :rtype: float
        """
        return self._inefficient_wait_time_in_sec

    @inefficient_wait_time_in_sec.setter
    def inefficient_wait_time_in_sec(self, inefficient_wait_time_in_sec):
        """
        Sets the inefficient_wait_time_in_sec of this SqlStatistics.
        Inefficient Wait Time in seconds


        :param inefficient_wait_time_in_sec: The inefficient_wait_time_in_sec of this SqlStatistics.
        :type: float
        """
        self._inefficient_wait_time_in_sec = inefficient_wait_time_in_sec

    @property
    def response_time_in_sec(self):
        """
        **[Required]** Gets the response_time_in_sec of this SqlStatistics.
        Response time is the average elaspsed time per execution. It is the ratio of Total Database Time to the number of executions


        :return: The response_time_in_sec of this SqlStatistics.
        :rtype: float
        """
        return self._response_time_in_sec

    @response_time_in_sec.setter
    def response_time_in_sec(self, response_time_in_sec):
        """
        Sets the response_time_in_sec of this SqlStatistics.
        Response time is the average elaspsed time per execution. It is the ratio of Total Database Time to the number of executions


        :param response_time_in_sec: The response_time_in_sec of this SqlStatistics.
        :type: float
        """
        self._response_time_in_sec = response_time_in_sec

    @property
    def plan_count(self):
        """
        **[Required]** Gets the plan_count of this SqlStatistics.
        Number of SQL execution plans used by the SQL


        :return: The plan_count of this SqlStatistics.
        :rtype: int
        """
        return self._plan_count

    @plan_count.setter
    def plan_count(self, plan_count):
        """
        Sets the plan_count of this SqlStatistics.
        Number of SQL execution plans used by the SQL


        :param plan_count: The plan_count of this SqlStatistics.
        :type: int
        """
        self._plan_count = plan_count

    @property
    def variability(self):
        """
        **[Required]** Gets the variability of this SqlStatistics.
        Variability is the ratio of the standard deviation in response time to the mean of response time of the SQL


        :return: The variability of this SqlStatistics.
        :rtype: float
        """
        return self._variability

    @variability.setter
    def variability(self, variability):
        """
        Sets the variability of this SqlStatistics.
        Variability is the ratio of the standard deviation in response time to the mean of response time of the SQL


        :param variability: The variability of this SqlStatistics.
        :type: float
        """
        self._variability = variability

    @property
    def average_active_sessions(self):
        """
        **[Required]** Gets the average_active_sessions of this SqlStatistics.
        Average Active Sessions represent the average active sessions at a point in time. It is the number of sessions that are either working or waiting.


        :return: The average_active_sessions of this SqlStatistics.
        :rtype: float
        """
        return self._average_active_sessions

    @average_active_sessions.setter
    def average_active_sessions(self, average_active_sessions):
        """
        Sets the average_active_sessions of this SqlStatistics.
        Average Active Sessions represent the average active sessions at a point in time. It is the number of sessions that are either working or waiting.


        :param average_active_sessions: The average_active_sessions of this SqlStatistics.
        :type: float
        """
        self._average_active_sessions = average_active_sessions

    @property
    def database_time_pct(self):
        """
        **[Required]** Gets the database_time_pct of this SqlStatistics.
        Percentage of Database Time


        :return: The database_time_pct of this SqlStatistics.
        :rtype: float
        """
        return self._database_time_pct

    @database_time_pct.setter
    def database_time_pct(self, database_time_pct):
        """
        Sets the database_time_pct of this SqlStatistics.
        Percentage of Database Time


        :param database_time_pct: The database_time_pct of this SqlStatistics.
        :type: float
        """
        self._database_time_pct = database_time_pct

    @property
    def inefficiency_in_pct(self):
        """
        **[Required]** Gets the inefficiency_in_pct of this SqlStatistics.
        Percentage of Inefficiency. It is calculated by Total Database Time divided by Total Wait Time


        :return: The inefficiency_in_pct of this SqlStatistics.
        :rtype: float
        """
        return self._inefficiency_in_pct

    @inefficiency_in_pct.setter
    def inefficiency_in_pct(self, inefficiency_in_pct):
        """
        Sets the inefficiency_in_pct of this SqlStatistics.
        Percentage of Inefficiency. It is calculated by Total Database Time divided by Total Wait Time


        :param inefficiency_in_pct: The inefficiency_in_pct of this SqlStatistics.
        :type: float
        """
        self._inefficiency_in_pct = inefficiency_in_pct

    @property
    def change_in_cpu_time_in_pct(self):
        """
        **[Required]** Gets the change_in_cpu_time_in_pct of this SqlStatistics.
        Percent change in CPU Time based on linear regression


        :return: The change_in_cpu_time_in_pct of this SqlStatistics.
        :rtype: float
        """
        return self._change_in_cpu_time_in_pct

    @change_in_cpu_time_in_pct.setter
    def change_in_cpu_time_in_pct(self, change_in_cpu_time_in_pct):
        """
        Sets the change_in_cpu_time_in_pct of this SqlStatistics.
        Percent change in CPU Time based on linear regression


        :param change_in_cpu_time_in_pct: The change_in_cpu_time_in_pct of this SqlStatistics.
        :type: float
        """
        self._change_in_cpu_time_in_pct = change_in_cpu_time_in_pct

    @property
    def change_in_io_time_in_pct(self):
        """
        **[Required]** Gets the change_in_io_time_in_pct of this SqlStatistics.
        Percent change in IO Time based on linear regression


        :return: The change_in_io_time_in_pct of this SqlStatistics.
        :rtype: float
        """
        return self._change_in_io_time_in_pct

    @change_in_io_time_in_pct.setter
    def change_in_io_time_in_pct(self, change_in_io_time_in_pct):
        """
        Sets the change_in_io_time_in_pct of this SqlStatistics.
        Percent change in IO Time based on linear regression


        :param change_in_io_time_in_pct: The change_in_io_time_in_pct of this SqlStatistics.
        :type: float
        """
        self._change_in_io_time_in_pct = change_in_io_time_in_pct

    @property
    def change_in_inefficient_wait_time_in_pct(self):
        """
        **[Required]** Gets the change_in_inefficient_wait_time_in_pct of this SqlStatistics.
        Percent change in Inefficient Wait Time based on linear regression


        :return: The change_in_inefficient_wait_time_in_pct of this SqlStatistics.
        :rtype: float
        """
        return self._change_in_inefficient_wait_time_in_pct

    @change_in_inefficient_wait_time_in_pct.setter
    def change_in_inefficient_wait_time_in_pct(self, change_in_inefficient_wait_time_in_pct):
        """
        Sets the change_in_inefficient_wait_time_in_pct of this SqlStatistics.
        Percent change in Inefficient Wait Time based on linear regression


        :param change_in_inefficient_wait_time_in_pct: The change_in_inefficient_wait_time_in_pct of this SqlStatistics.
        :type: float
        """
        self._change_in_inefficient_wait_time_in_pct = change_in_inefficient_wait_time_in_pct

    @property
    def change_in_response_time_in_pct(self):
        """
        **[Required]** Gets the change_in_response_time_in_pct of this SqlStatistics.
        Percent change in Response Time based on linear regression


        :return: The change_in_response_time_in_pct of this SqlStatistics.
        :rtype: float
        """
        return self._change_in_response_time_in_pct

    @change_in_response_time_in_pct.setter
    def change_in_response_time_in_pct(self, change_in_response_time_in_pct):
        """
        Sets the change_in_response_time_in_pct of this SqlStatistics.
        Percent change in Response Time based on linear regression


        :param change_in_response_time_in_pct: The change_in_response_time_in_pct of this SqlStatistics.
        :type: float
        """
        self._change_in_response_time_in_pct = change_in_response_time_in_pct

    @property
    def change_in_average_active_sessions_in_pct(self):
        """
        **[Required]** Gets the change_in_average_active_sessions_in_pct of this SqlStatistics.
        Percent change in Average Active Sessions based on linear regression


        :return: The change_in_average_active_sessions_in_pct of this SqlStatistics.
        :rtype: float
        """
        return self._change_in_average_active_sessions_in_pct

    @change_in_average_active_sessions_in_pct.setter
    def change_in_average_active_sessions_in_pct(self, change_in_average_active_sessions_in_pct):
        """
        Sets the change_in_average_active_sessions_in_pct of this SqlStatistics.
        Percent change in Average Active Sessions based on linear regression


        :param change_in_average_active_sessions_in_pct: The change_in_average_active_sessions_in_pct of this SqlStatistics.
        :type: float
        """
        self._change_in_average_active_sessions_in_pct = change_in_average_active_sessions_in_pct

    @property
    def change_in_executions_per_hour_in_pct(self):
        """
        **[Required]** Gets the change_in_executions_per_hour_in_pct of this SqlStatistics.
        Percent change in Executions per hour based on linear regression


        :return: The change_in_executions_per_hour_in_pct of this SqlStatistics.
        :rtype: float
        """
        return self._change_in_executions_per_hour_in_pct

    @change_in_executions_per_hour_in_pct.setter
    def change_in_executions_per_hour_in_pct(self, change_in_executions_per_hour_in_pct):
        """
        Sets the change_in_executions_per_hour_in_pct of this SqlStatistics.
        Percent change in Executions per hour based on linear regression


        :param change_in_executions_per_hour_in_pct: The change_in_executions_per_hour_in_pct of this SqlStatistics.
        :type: float
        """
        self._change_in_executions_per_hour_in_pct = change_in_executions_per_hour_in_pct

    @property
    def change_in_inefficiency_in_pct(self):
        """
        **[Required]** Gets the change_in_inefficiency_in_pct of this SqlStatistics.
        Percent change in Inefficiency based on linear regression


        :return: The change_in_inefficiency_in_pct of this SqlStatistics.
        :rtype: float
        """
        return self._change_in_inefficiency_in_pct

    @change_in_inefficiency_in_pct.setter
    def change_in_inefficiency_in_pct(self, change_in_inefficiency_in_pct):
        """
        Sets the change_in_inefficiency_in_pct of this SqlStatistics.
        Percent change in Inefficiency based on linear regression


        :param change_in_inefficiency_in_pct: The change_in_inefficiency_in_pct of this SqlStatistics.
        :type: float
        """
        self._change_in_inefficiency_in_pct = change_in_inefficiency_in_pct

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class NetworkLoadBalancerClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.network_load_balancer.NetworkLoadBalancerClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new NetworkLoadBalancerClientCompositeOperations object

        :param NetworkLoadBalancerClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def change_network_load_balancer_compartment_and_wait_for_state(self, network_load_balancer_id, change_network_load_balancer_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.change_network_load_balancer_compartment` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.ChangeNetworkLoadBalancerCompartmentDetails change_network_load_balancer_compartment_details: (required)
            The configuration details for moving a network load balancer to a different compartment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.change_network_load_balancer_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_network_load_balancer_compartment(network_load_balancer_id, change_network_load_balancer_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_backend_and_wait_for_state(self, network_load_balancer_id, create_backend_details, backend_set_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_backend` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.CreateBackendDetails create_backend_details: (required)
            The details to add a backend server to a backend set.

        :param str backend_set_name: (required)
            The name of the backend set to which to add the backend server.

            Example: `example_backend_set`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_backend`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_backend(network_load_balancer_id, create_backend_details, backend_set_name, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_backend_set_and_wait_for_state(self, network_load_balancer_id, create_backend_set_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_backend_set` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.CreateBackendSetDetails create_backend_set_details: (required)
            The details for adding a backend set.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_backend_set`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_backend_set(network_load_balancer_id, create_backend_set_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_listener_and_wait_for_state(self, network_load_balancer_id, create_listener_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_listener` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.CreateListenerDetails create_listener_details: (required)
            Details to add a listener.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_listener`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_listener(network_load_balancer_id, create_listener_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_network_load_balancer_and_wait_for_state(self, create_network_load_balancer_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_network_load_balancer` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param oci.network_load_balancer.models.CreateNetworkLoadBalancerDetails create_network_load_balancer_details: (required)
            Details for the new network load balancer.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_network_load_balancer`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_network_load_balancer(create_network_load_balancer_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_backend_and_wait_for_state(self, network_load_balancer_id, backend_set_name, backend_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_backend` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str backend_set_name: (required)
            The name of the backend set associated with the backend server.

            Example: `example_backend_set`

        :param str backend_name: (required)
            The name of the backend server to remove. This is specified as <ip>:<port>, or as <ip> <OCID>:<port>.

            Example: `10.0.0.3:8080` or `ocid1.privateip..oc1.<var>&lt;unique_ID&gt;</var>:8080`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_backend`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_backend(network_load_balancer_id, backend_set_name, backend_name, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_backend_set_and_wait_for_state(self, network_load_balancer_id, backend_set_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_backend_set` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str backend_set_name: (required)
            The name of the backend set to delete.

            Example: `example_backend_set`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_backend_set`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_backend_set(network_load_balancer_id, backend_set_name, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_listener_and_wait_for_state(self, network_load_balancer_id, listener_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_listener` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str listener_name: (required)
            The name of the listener to delete.

            Example: `example_listener`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_listener`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_listener(network_load_balancer_id, listener_name, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_network_load_balancer_and_wait_for_state(self, network_load_balancer_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_network_load_balancer` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_network_load_balancer`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_network_load_balancer(network_load_balancer_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_backend_and_wait_for_state(self, network_load_balancer_id, update_backend_details, backend_set_name, backend_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_backend` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.UpdateBackendDetails update_backend_details: (required)
            Details for updating a backend server.

        :param str backend_set_name: (required)
            The name of the backend set associated with the backend server.

            Example: `example_backend_set`

        :param str backend_name: (required)
            The name of the backend server to update. This is specified as <ip>:<port>, or as <ip> <OCID>:<port>.

            Example: `10.0.0.3:8080` or `ocid1.privateip..oc1.<var>&lt;unique_ID&gt;</var>:8080`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_backend`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_backend(network_load_balancer_id, update_backend_details, backend_set_name, backend_name, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_backend_set_and_wait_for_state(self, network_load_balancer_id, update_backend_set_details, backend_set_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_backend_set` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.UpdateBackendSetDetails update_backend_set_details: (required)
            The details to update a backend set.

        :param str backend_set_name: (required)
            The name of the backend set to update.

            Example: `example_backend_set`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_backend_set`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_backend_set(network_load_balancer_id, update_backend_set_details, backend_set_name, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_health_checker_and_wait_for_state(self, network_load_balancer_id, update_health_checker_details, backend_set_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_health_checker` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.UpdateHealthCheckerDetails update_health_checker_details: (required)
            The health check policy configuration details.

        :param str backend_set_name: (required)
            The name of the backend set associated with the health check policy to be retrieved.

            Example: `example_backend_set`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_health_checker`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_health_checker(network_load_balancer_id, update_health_checker_details, backend_set_name, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_listener_and_wait_for_state(self, network_load_balancer_id, update_listener_details, listener_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_listener` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.UpdateListenerDetails update_listener_details: (required)
            Details to update a listener.

        :param str listener_name: (required)
            The name of the listener to update.

            Example: `example_listener`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_listener`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_listener(network_load_balancer_id, update_listener_details, listener_name, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_network_load_balancer_and_wait_for_state(self, network_load_balancer_id, update_network_load_balancer_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_network_load_balancer` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.UpdateNetworkLoadBalancerDetails update_network_load_balancer_details: (required)
            The information to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_network_load_balancer`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_network_load_balancer(network_load_balancer_id, update_network_load_balancer_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_network_security_groups_and_wait_for_state(self, network_load_balancer_id, update_network_security_groups_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_network_security_groups` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.UpdateNetworkSecurityGroupsDetails update_network_security_groups_details: (required)
            The details for updating the network security groups associated with the specified network load balancer.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_network_security_groups`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_network_security_groups(network_load_balancer_id, update_network_security_groups_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SteeringPolicyAnswer(object):
    """
    DNS record data with metadata for processing in a steering policy.


    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SteeringPolicyAnswer object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this SteeringPolicyAnswer.
        :type name: str

        :param rtype:
            The value to assign to the rtype property of this SteeringPolicyAnswer.
        :type rtype: str

        :param rdata:
            The value to assign to the rdata property of this SteeringPolicyAnswer.
        :type rdata: str

        :param pool:
            The value to assign to the pool property of this SteeringPolicyAnswer.
        :type pool: str

        :param is_disabled:
            The value to assign to the is_disabled property of this SteeringPolicyAnswer.
        :type is_disabled: bool

        """
        self.swagger_types = {
            'name': 'str',
            'rtype': 'str',
            'rdata': 'str',
            'pool': 'str',
            'is_disabled': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'rtype': 'rtype',
            'rdata': 'rdata',
            'pool': 'pool',
            'is_disabled': 'isDisabled'
        }

        self._name = None
        self._rtype = None
        self._rdata = None
        self._pool = None
        self._is_disabled = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this SteeringPolicyAnswer.
        A user-friendly name for the answer, unique within the steering policy.
        An answer's `name` property can be referenced in `answerCondition` properties
        of rules using `answer.name`.

        **Example:**

          \"rules\": [
            {
              \"ruleType\": \"FILTER\",
              \"defaultAnswerData\":  [
                {
                  \"answerCondition\": \"answer.name == 'server 1'\",
                  \"shouldKeep\": true
                }
              ]
            }
          ]


        :return: The name of this SteeringPolicyAnswer.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SteeringPolicyAnswer.
        A user-friendly name for the answer, unique within the steering policy.
        An answer's `name` property can be referenced in `answerCondition` properties
        of rules using `answer.name`.

        **Example:**

          \"rules\": [
            {
              \"ruleType\": \"FILTER\",
              \"defaultAnswerData\":  [
                {
                  \"answerCondition\": \"answer.name == 'server 1'\",
                  \"shouldKeep\": true
                }
              ]
            }
          ]


        :param name: The name of this SteeringPolicyAnswer.
        :type: str
        """
        self._name = name

    @property
    def rtype(self):
        """
        **[Required]** Gets the rtype of this SteeringPolicyAnswer.
        The type of DNS record, such as A or CNAME. Only A, AAAA, and CNAME are supported. For more
        information, see `Supported DNS Resource Record Types`__.

        __ https://docs.cloud.oracle.com/iaas/Content/DNS/Reference/supporteddnsresource.htm


        :return: The rtype of this SteeringPolicyAnswer.
        :rtype: str
        """
        return self._rtype

    @rtype.setter
    def rtype(self, rtype):
        """
        Sets the rtype of this SteeringPolicyAnswer.
        The type of DNS record, such as A or CNAME. Only A, AAAA, and CNAME are supported. For more
        information, see `Supported DNS Resource Record Types`__.

        __ https://docs.cloud.oracle.com/iaas/Content/DNS/Reference/supporteddnsresource.htm


        :param rtype: The rtype of this SteeringPolicyAnswer.
        :type: str
        """
        self._rtype = rtype

    @property
    def rdata(self):
        """
        **[Required]** Gets the rdata of this SteeringPolicyAnswer.
        The record's data, as whitespace-delimited tokens in
        type-specific presentation format. All RDATA is normalized and the
        returned presentation of your RDATA may differ from its initial input.
        For more information about RDATA, see `Supported DNS Resource Record Types`__.

        __ https://docs.cloud.oracle.com/iaas/Content/DNS/Reference/supporteddnsresource.htm


        :return: The rdata of this SteeringPolicyAnswer.
        :rtype: str
        """
        return self._rdata

    @rdata.setter
    def rdata(self, rdata):
        """
        Sets the rdata of this SteeringPolicyAnswer.
        The record's data, as whitespace-delimited tokens in
        type-specific presentation format. All RDATA is normalized and the
        returned presentation of your RDATA may differ from its initial input.
        For more information about RDATA, see `Supported DNS Resource Record Types`__.

        __ https://docs.cloud.oracle.com/iaas/Content/DNS/Reference/supporteddnsresource.htm


        :param rdata: The rdata of this SteeringPolicyAnswer.
        :type: str
        """
        self._rdata = rdata

    @property
    def pool(self):
        """
        Gets the pool of this SteeringPolicyAnswer.
        The freeform name of a group of one or more records in which this record is included,
        such as \"LAX data center\". An answer's `pool` property can be referenced in `answerCondition`
        properties of rules using `answer.pool`.

        **Example:**

          \"rules\": [
            {
              \"ruleType\": \"FILTER\",
              \"defaultAnswerData\":  [
                {
                  \"answerCondition\": \"answer.pool == 'US East Servers'\",
                  \"shouldKeep\": true
                }
              ]
            }
          ]


        :return: The pool of this SteeringPolicyAnswer.
        :rtype: str
        """
        return self._pool

    @pool.setter
    def pool(self, pool):
        """
        Sets the pool of this SteeringPolicyAnswer.
        The freeform name of a group of one or more records in which this record is included,
        such as \"LAX data center\". An answer's `pool` property can be referenced in `answerCondition`
        properties of rules using `answer.pool`.

        **Example:**

          \"rules\": [
            {
              \"ruleType\": \"FILTER\",
              \"defaultAnswerData\":  [
                {
                  \"answerCondition\": \"answer.pool == 'US East Servers'\",
                  \"shouldKeep\": true
                }
              ]
            }
          ]


        :param pool: The pool of this SteeringPolicyAnswer.
        :type: str
        """
        self._pool = pool

    @property
    def is_disabled(self):
        """
        Gets the is_disabled of this SteeringPolicyAnswer.
        Set this property to `true` to indicate that the answer is administratively disabled,
        such as when the corresponding server is down for maintenance. An answer's `isDisabled`
        property can be referenced in `answerCondition` properties in rules using `answer.isDisabled`.

        **Example:**
          \"rules\": [
            {
              \"ruleType\": \"FILTER\",
              \"defaultAnswerData\": [
                {
                  \"answerCondition\": \"answer.isDisabled != true\",
                  \"shouldKeep\": true
                }
              ]
            },


        :return: The is_disabled of this SteeringPolicyAnswer.
        :rtype: bool
        """
        return self._is_disabled

    @is_disabled.setter
    def is_disabled(self, is_disabled):
        """
        Sets the is_disabled of this SteeringPolicyAnswer.
        Set this property to `true` to indicate that the answer is administratively disabled,
        such as when the corresponding server is down for maintenance. An answer's `isDisabled`
        property can be referenced in `answerCondition` properties in rules using `answer.isDisabled`.

        **Example:**
          \"rules\": [
            {
              \"ruleType\": \"FILTER\",
              \"defaultAnswerData\": [
                {
                  \"answerCondition\": \"answer.isDisabled != true\",
                  \"shouldKeep\": true
                }
              ]
            },


        :param is_disabled: The is_disabled of this SteeringPolicyAnswer.
        :type: bool
        """
        self._is_disabled = is_disabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
